diff --git a/main.c b/main.c
index c74f33c..fc020ee 100644
--- a/main.c
+++ b/main.c
@@ -6,6 +6,8 @@
 #include <GLFW/glfw3.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <vector.h>
+#include <math.h>
 
 // ファイルパスを構築（プラットフォームに応じて）
 char *constructFilePath(const char *basePath) {
@@ -222,9 +224,33 @@ int main(int argc, char **argv) {
     // シェーダープログラムを使用
     glUseProgram(shaderProgram);
 
+    // 時間に基づいて色をアニメーション
+    float time = (float)glfwGetTime();
+    float speed = 1.0f; // アニメーションの速度
+    float phase = 2.0f * 3.14159f / 3.0f; // // 120度の位相差（3色用）
+
+    // uColorA: 赤 -> 緑 -> 青
+    Vector3 colorA;
+    colorA.r = sin(time * speed + 0.0f) * 0.5f + 0.5f; // 0.0 to 1.0
+    colorA.g = sin(time * speed + phase) * 0.5f + 0.5f;
+    colorA.b = sin(time * speed + 2.0f * phase) * 0.5f + 0.5f;
+
+    // uColorB: 緑 -> 青 -> 赤
+    Vector3 colorB;
+    colorB.r = sin(time * speed + 2.0f * phase) * 0.5f + 0.5f;
+    colorB.g = sin(time * speed + 0.0f) * 0.5f + 0.5f;
+    colorB.b = sin(time * speed + phase) * 0.5f + 0.5f;
+
+    // uColorC: 青 -> 赤 -> 緑
+    Vector3 colorC;
+    colorC.r = sin(time * speed + phase) * 0.5f + 0.5f;
+    colorC.g = sin(time * speed + 2.0f * phase) * 0.5f + 0.5f;
+    colorC.b = sin(time * speed + 0.0f) * 0.5f + 0.5f;
+
     // ユニフォームを設定
-    glUniform3f(glGetUniformLocation(shaderProgram, "uColorA"), 1.0f, 0.0f, 0.0f); // 赤
-    glUniform3f(glGetUniformLocation(shaderProgram, "uColorB"), 0.0f, 1.0f, 0.0f); // 緑
+    glUniform3f(glGetUniformLocation(shaderProgram, "uColorA"), colorA.r, colorA.g, colorA.b); // 赤
+    glUniform3f(glGetUniformLocation(shaderProgram, "uColorB"), colorB.r, colorB.g, colorB.b); // 緑
+    glUniform3f(glGetUniformLocation(shaderProgram, "uColorC"), colorC.r, colorC.g, colorC.b); // 青
 
     // クアッドを描画
     glBindVertexArray(VAO);
diff --git a/shader/fragment.glsl b/shader/fragment.glsl
index e51d602..51b432e 100644
--- a/shader/fragment.glsl
+++ b/shader/fragment.glsl
@@ -5,8 +5,10 @@ out vec4 out_color;
 
 uniform vec3 uColorA;
 uniform vec3 uColorB;
+uniform vec3 uColorC;
 
 void main() {
-  vec3 blendedColor = mix(uColorA, uColorB, vUv.x);
+  vec3 temp = mix(uColorA, uColorB, vUv.x);
+  vec3 blendedColor = mix(temp, uColorC, vUv.y * 0.95);
   out_color = vec4(blendedColor, 1.0);
 }
\ No newline at end of file
